@@ -1,15 +1,5 @@
-#' tweets_df
-#'
-#' @description Converts tweets object (nested list converted from
-#'   json object) into a [tibble] data frame.
-#'
-#' @param dat Tweets object or nested list. Usually this is the
-#'   return object produced by \code{\link{search_tweets}} or
-#'   \code{\link{stream_tweets}}.
-#'
-#' @importFrom dplyr bind_cols
-#' @export
-tweets_df <- function(dat) {
+
+tweets_df <- function(dat, clean_tweets = TRUE) {
 
   if (missing(dat)) {
     stop("Must specify tweets object, dat.", call. = TRUE)
@@ -23,96 +13,99 @@ tweets_df <- function(dat) {
     dat <- dat[["status"]]
   }
 
-  tweets_df <- bind_cols(
+  tweets_df <- cbind_(
     tweets_toplevel_df(dat),
     tweets_entities_df(dat),
     tweets_retweet_df(dat),
     tweets_place_df(dat))
 
-  tweets_df
+  if (clean_tweets) {
+    tweets_df[["text"]] <- clean_tweets(tweets_df[["text"]])
+  }
+  unique(tweets_df)
 }
 
-#' user_df
+#' clean_tweets
 #'
-#' @description Converts user object (nested list converted from
-#'   json object) into a [tibble] data frame.
+#' @description Converts tweets to to ASCII
+#' @param x Twitter text
 #'
-#' @param dat User object or nested list. Usually this is the
-#'   return object produced by \code{\link{lookup_users}}.
-#'
-#' @importFrom dplyr bind_cols
 #' @export
+clean_tweets <- function(x) {
+  iconv(x, "UTF-8", "ASCII", "")
+}
+
+#' utf8_tweets
+#'
+#' @description Converts tweets to UTF-8 encoding
+#' @param x Twitter text
+#'
+#' @export
+utf8_tweets <- function(x) {
+	unlist(lapply(x, function(.) if (Encoding(.) != "UTF-8") enc2utf8(x)),
+		recursive = FALSE)
+}
+
+
 user_df <- function(dat) {
 
   if ("user" %in% names(dat)) {
     dat <- dat[["user"]]
   }
 
-  user_df <- bind_cols(
+  user_df <- cbind_(
     user_toplevel_df(dat),
     user_entities_df(dat))
 
-  user_df
+  unique(user_df)
 }
 
 #' parser
 #'
-#' @description Parses tweets and users objects. Returns data frames
-#'   for each.
-#'
-#' @param x List, fromJSON nested list object
-#' @param n Numeric, number of desired tweets to return
-#'
-#' @importFrom dplyr bind_rows
-#' @noRd
+#' @param x nested list of API data returned from fromJSON
+#' @param n desired number to return
+#' @keywords internal
+#' @export
 parser <- function(x, n = NULL) {
-  if (is.data.frame(x)) {
+  tweets <- data.frame()
+  users <- data.frame()
+
+  if (all(is.data.frame(x), "id_str" %in% names(x))) {
     tweets <- parse_tweets(x)
     users <- parse_users(x)
   } else {
     stopifnot(is.list(x))
-
     tweets <- bply(x, parse_tweets)
-    tweets <- n_rows(tweets, n)
-
     users <- bply(x, parse_users)
-    users <- n_rows(users, n)
   }
 
-  list(
-    tweets = tweets,
-    users = users)
+  tweets <- return_n_rows(tweets, n)
+  tweets <- tweets[!is.na(tweets$status_id), ]
+  tweets <- unique(tweets)
+  users <- return_n_rows(users, n)
+  if (is.data.frame(users)) {
+  	users <- filter_na_rows(users)
+  }
+  list(tweets = tweets, users = users)
 }
 
-#' parse_fs
-#'
-#' @description Returns next_cursor and tibble data frame of user
-#'   ids.
-#'
-#' @param x List, nested fromJSON object.
-#' @param n Numeric, number of desired ids to return.
-#' @return List of length 2, containing next_cursor (to be used
-#'   with \code{page} argument in loops to collect maxiimum ids)
-#'   and ids data frame (of followers or friends depending on
-#'   parent function used to generate x input).
-#'
-#' @noRd
-#' @importFrom dplyr tbl_df
+
 parse_fs <- function(x, n = NULL) {
   if (length(x) == 1) {
     next_cursor <- x[[1]][["next_cursor_str"]]
-    x <- x[[1]][["ids"]]
+    x <- as.double(x[[1]][["ids"]])
   } else if (length(x) > 1) {
     next_cursor <- unlist(lapply(x, function(x) x[["next_cursor_str"]]))
     next_cursor <- return_last(next_cursor)
     x <- unlist(lapply(x, function(x) x[["ids"]]))
   }
-  if (!is.null(n)) {
-    if (n < length(x)) {
-      x <- x[seq_along(n)]
-    }
-  }
-  list(next_cursor = next_cursor, ids = tbl_df(x))
+
+  x <- return_n_rows(x, n)
+  x <- data_frame_(x)
+  names(x) <- "ids"
+
+  attr(x, "next_cursor") <- next_cursor
+  x
 }
 
 parse_tweets <- function(x) {
@@ -130,6 +123,23 @@ parse_tweets <- function(x) {
   return(invisible())
 }
 
+parse_users <- function(x) {
+
+  if ("friends_count" %in% names(x)) {
+    return(user_df(x))
+  }
+
+  if ("statuses" %in% names(x)) {
+    x <- x[["statuses"]]
+  }
+
+  if ("user" %in% names(x)) {
+    return(user_df(x[["user"]]))
+  }
+
+  return(invisible())
+}
+
 check_user_obj <- function(x) {
 
   if ("user" %in% names(x)) {
