@@ -12,20 +12,19 @@
 #' @seealso \url{https://dev.twitter.com/overview/documentation}
 #' @examples
 #' \dontrun{
-#' # search for 1000 tweets mentioning Hillary Clinton
-#' hrc <- search_tweets(q = "hillaryclinton", count = 1000)
+#' # lookup vector of 1 or more user_id or screen_name
+#' users <- c("potus", "hillaryclinton", "realdonaldtrump",
+#'   "fivethirtyeight", "cnn", "espn", "twitter")
 #'
-#' # lookup returned user_id values
-#' users <- lookup_users(hrc$user_id)
-#' users
+#' usr_df <- lookup_users(users)
+#' usr_df
 #'
-#' # merge data objects
-#' dat <- dplyr::left_join(hrc, users, by = "user_id")
-#' dat
+#' # view tweet data for these users via tweets_data()
+#' tweets_data(usr_df)
 #' }
 #'
 #' @return json response object (max is 18000 per token)
-#' @importFrom dplyr bind_rows data_frame
+#' @family users
 #' @export
 lookup_users <- function(users, token = NULL, parse = TRUE) {
 
@@ -59,7 +58,10 @@ lookup_users <- function(users, token = NULL, parse = TRUE) {
     if (from > length(users)) break
   }
 
-  if (parse) usr <- parser(usr)
+  if (parse) {
+    usr <- parser(usr)
+    usr <- attr_tweetusers(usr[c("users", "tweets")])
+  }
 
   usr
 }
